import { Context, HelpInfo } from './command';
import { Printable } from './object';
import { ExpectedError } from './error';
export interface CommandModule {
    brief?: string;
    description?: string;
    subcommands?: SubcommandDescriptor[];
}
export interface SubcommandDescriptor {
    name: string;
    filename?: string;
    alias?: string;
    aliases?: string[];
    brief?: string;
}
/**
 * Clime command line interface.
 */
export declare class CLI {
    /** Command entry name. */
    name: string;
    root: string;
    constructor(
        /** Command entry name. */
        name: string, 
        /** Root directory of command modules. */
        root: string);
    execute(argv: string[], cwd?: string): Promise<any>;
    /**
     * Mapping the command line arguments to a specific command file.
     */
    private preProcessArguments(argv);
    private executeCommand(command, commandArgs, commandExtraArgs, commandOptions, context);
    getHelp(): Promise<HelpInfo>;
}
export interface ParsedArgs {
    args: any[];
    extraArgs?: any[];
    options?: Clime.Dictionary<any>;
    context?: Context;
}
export interface HelpProvider {
    getHelp(): Promise<HelpInfo> | HelpInfo;
}
export declare class UsageError extends ExpectedError implements Printable {
    helpProvider: HelpProvider;
    constructor(message: string, helpProvider: HelpProvider);
    print(stdout: NodeJS.WritableStream, stderr: NodeJS.WritableStream): Promise<void>;
}
